@@ -647,12 +647,6 @@ int RGWRados::store_bucket_info(RGWBucketInfo& info, map<string, bufferlist> *pa
   if (ret < 0)
     return ret;
 
-  ret = rgw_put_obj(info.owner, pi_buckets_rados, info.bucket.bucket_id, bl.c_str(), bl.length(), false, pattrs);
-  if (ret < 0) {
-    ldout(cct, 0) << "ERROR: failed to store " << pi_buckets_rados << ":" << info.bucket.bucket_id << " ret=" << ret << dendl;
-    return ret;
-  }
-
   ldout(cct, 20) << "store_bucket_info: bucket=" << info.bucket << " owner " << info.owner << dendl;
   return 0;
 }
@@ -2747,7 +2741,8 @@ int RGWRados::cls_obj_usage_log_trim(string& oid, string& user, uint64_t start_e
     return r;
 
   bufferlist in, out;
-  rgw_cls_usage_log_read_op call;
+  rgw_cls_usage_log_trim_op call;
+  call.user = user;
   call.start_epoch = start_epoch;
   call.end_epoch = end_epoch;
   ::encode(call, in);
